==> datarobot_model_metrics-0.1.0-py2.py3-none-any.whl: dmm/metric/metric_base.py <==
import numpy as np
import pandas as pd


class MetricBase(object):
    def __init__(
        self,
        name,
        description=None,
        need_predictions=False,
        need_actuals=False,
        need_scoring_data=False,
        need_training_data=False,
    ):
        self.name = name
        self.description = description
        self._need_predictions = need_predictions
        self._need_actuals = need_actuals
        self._need_scoring_data = need_scoring_data
        self._need_training_data = need_training_data

    def __str__(self):
        s = "name: {}, description: {}".format(self.name, self.description)
        s += "\nneed_training_data: {}".format(self._need_training_data)
        s += "\nneed_scoring_data:  {}".format(self._need_scoring_data)
        s += "\nneed_predictions:   {}".format(self._need_predictions)
        s += "\nneed_actuals:       {}".format(self._need_actuals)
        return s

    def need_predictions(self):
        """
        Should return True if this metric need predictions
        """
        return self._need_predictions

    def need_actuals(self):
        """
        Should return True if this metric need actuals. If true, both predictions and acutals
        will be provided
        """
        return self._need_actuals

    def need_scoring_data(self):
        """
        Should return True if this metric need scoring data.
        :return:
        """
        return self._need_scoring_data

    def need_training_data(self):
        """
        Should return True if this metric need training data.
        :return:
        """
        return self._need_training_data

    def fit(self, training_data=None) -> object:
        """
        This method get access to the training data and is able to generate a context object
        which is passed to each call to the transform method.
        :param training_data:
        :return:
        """
        return None

    def score(
        self,
        scoring_data=pd.DataFrame,
        predictions=np.array,
        actuals=np.array,
        fit_ctx=None,
        metadata=None,
    ) -> float:
        raise NotImplemented

    def reduce_func(self) -> callable:
        return np.mean

        # this functionality is currently unused, but the idea is:
        # transform is applied to chunks of the scoring data.
        # the resulting values are then aggregated using this reduce
        # were that implemented, the transforms could return arbitrary output and only this reduce
        # would be forced to return a float
        # return func(
        #     (
        #         self.transform(data_chunk['scoring_data'], data_chunk['predictions'], data_chunk['actuals'])
        #         for data_chunk in data_stream
        #     )
        # )
        # raise NotImplemented


class ModelMetricBase(MetricBase):
    def __init__(self, name, description=None, need_training_data=False):
        super().__init__(
            name=name,
            description=description,
            need_scoring_data=False,
            need_predictions=True,
            need_actuals=True,
            need_training_data=need_training_data,
        )

    def score(
        self,
        scoring_data=None,
        prediction=np.array,
        actuals=np.array,
        fit_context=None,
        metadata=None,
    ) -> float:
        raise NotImplemented


class DataMetricBase(MetricBase):
    def __init__(self, name, description=None, need_training_data=False):
        super().__init__(
            name=name,
            description=description,
            need_scoring_data=True,
            need_predictions=False,
            need_actuals=False,
            need_training_data=need_training_data,
        )

    def score(
        self,
        scoring_data=pd.DataFrame,
        fit_ctx=None,
        metadata=None,
        predictions=None,
        actuals=None,
    ) -> float:
        raise NotImplemented

==> datarobot_model_metrics-0.1.6-py2.py3-none-any.whl: dmm/metric/metric_base.py <==
import numpy as np
import pandas as pd


class MetricBase(object):
    def __init__(
        self,
        name: str,
        description: str = None,
        need_predictions: bool = False,
        need_actuals: bool = False,
        need_scoring_data: bool = False,
        need_training_data: bool = False,
    ):
        self.name = name
        self.description = description
        self._need_predictions = need_predictions
        self._need_actuals = need_actuals
        self._need_scoring_data = need_scoring_data
        self._need_training_data = need_training_data

    def __str__(self):
        s = "name: {}, description: {}".format(self.name, self.description)
        s += "\nneed_training_data: {}".format(self._need_training_data)
        s += "\nneed_scoring_data:  {}".format(self._need_scoring_data)
        s += "\nneed_predictions:   {}".format(self._need_predictions)
        s += "\nneed_actuals:       {}".format(self._need_actuals)
        return s

    def need_predictions(self) -> bool:
        """
        Should return True if this metric need predictions
        :return bool:
        """
        return self._need_predictions

    def need_actuals(self) -> bool:
        """
        Should return True if this metric need actuals. If true, both predictions and acutals
        will be provided
        :return bool:
        """
        return self._need_actuals

    def need_scoring_data(self) -> bool:
        """
        Should return True if this metric need scoring data.
        :return bool:
        """
        return self._need_scoring_data

    def need_training_data(self) -> bool:
        """
        Should return True if this metric need training data.
        :return bool:
        """
        return self._need_training_data

    def fit(self, training_data: pd.DataFrame = None) -> object:
        """
        This method get access to the training data and is able to generate a context object
        which is passed to each call to the transform method.
        :param training_data:
        :return:
        """
        return None

    def score(
        self,
        scoring_data: pd.DataFrame,
        predictions: np.array,
        actuals: np.array,
        fit_ctx=None,
        metadata=None,
    ) -> float:
        raise NotImplemented

    def reduce_func(self) -> callable:
        return np.mean


class ModelMetricBase(MetricBase):
    def __init__(
        self, name: str, description: str = None, need_training_data: bool = False
    ):
        super().__init__(
            name=name,
            description=description,
            need_scoring_data=False,
            need_predictions=True,
            need_actuals=True,
            need_training_data=need_training_data,
        )

    def score(
        self,
        prediction: np.array,
        actuals: np.array,
        scoring_data=None,
        fit_context=None,
        metadata=None,
    ) -> float:
        raise NotImplemented


class DataMetricBase(MetricBase):
    def __init__(
        self, name: str, description: str = None, need_training_data: bool = False
    ):
        super().__init__(
            name=name,
            description=description,
            need_scoring_data=True,
            need_predictions=False,
            need_actuals=False,
            need_training_data=need_training_data,
        )

    def score(
        self,
        scoring_data: pd.DataFrame,
        fit_ctx=None,
        metadata=None,
        predictions=None,
        actuals=None,
    ) -> float:
        raise NotImplemented
